Yex.WeakLink (y_ex v0.10.5)
View Source⚠️ Experimental
A weak link to a value in a shared map.
Type Safety Note: WeakLink does not store runtime type information. Callers must use the correct method based on the original source type:
to_string/1for Text/XMLText quotesto_list/1for Array quotesderef/1for Map links
Calling the wrong method may result in undefined behavior or panics.
Summary
Functions
Converts the weak link to its preliminary representation.
Dereferences the (Map) weak link to obtain the actual value it points to.
Converts the (Array) weak link to a list of its elements.
Converts the (Text/XMLText) weak link to its string representation.
Types
Functions
@spec as_prelim(t()) :: Yex.WeakPrelim.t()
Converts the weak link to its preliminary representation.
Dereferences the (Map) weak link to obtain the actual value it points to.
Converts the (Array) weak link to a list of its elements.
Converts the (Text/XMLText) weak link to its string representation.